==> libreoffice-still-sdk-24.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1CellProperties =
[
    [ "UserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aa45a411ca57701213624a7c07e4c2da7", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "BackColor", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a5e27a55a4308a6862dec0a580fa3d201", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "BackTransparent", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ae5bf2cbe8fd11ee5aa797178a0f2c31d", null ],
    [ "BottomBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a76ed69ba5cbc1b15fa0d64aca4850106", null ],
    [ "BottomBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#afd16edc08d37e72058487182531f8c61", null ],
    [ "CellName", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a3af50fe66de4815d1516bd715370fe1f", null ],
    [ "HasTextChangesOnly", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aae144a800140779c1fc11cbf3fdf6fa0", null ],
    [ "IsProtected", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aaad2943237579803626aa6f3cde07295", null ],
    [ "LeftBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#afc5673d7ea472362ba3dfd1f1b891f3c", null ],
    [ "LeftBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aa525416639863f2dbee49aff512d0edc", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "ParentText", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a372da0ad466934275ff7b0c4d4024ef3", null ],
    [ "RightBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a5a63000f5a2a2472e3e4ff55b3acea68", null ],
    [ "RightBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aef3133d206f65e7c63e6f4e0b7e81a9b", null ],
    [ "TextSection", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a88ee79bd1b53330752b6a013f7c2cf65", null ],
    [ "TopBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a17ab3611edf21b072bf9963d28fbba0d", null ],
    [ "TopBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a244f38805668926e16165aab20b80f01", null ],
    [ "VertOrient", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a06b5322c78bfdcb3086a7bfd82285d40", null ]
];

==> libreoffice-still-sdk-25.2.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1CellProperties =
[
    [ "com::sun::star::xml::UserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aa45a411ca57701213624a7c07e4c2da7", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "BackColor", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a5e27a55a4308a6862dec0a580fa3d201", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "BackTransparent", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#ae5bf2cbe8fd11ee5aa797178a0f2c31d", null ],
    [ "BottomBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a76ed69ba5cbc1b15fa0d64aca4850106", null ],
    [ "BottomBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#afd16edc08d37e72058487182531f8c61", null ],
    [ "CellName", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a3af50fe66de4815d1516bd715370fe1f", null ],
    [ "HasTextChangesOnly", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aae144a800140779c1fc11cbf3fdf6fa0", null ],
    [ "IsProtected", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aaad2943237579803626aa6f3cde07295", null ],
    [ "LeftBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#afc5673d7ea472362ba3dfd1f1b891f3c", null ],
    [ "LeftBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aa525416639863f2dbee49aff512d0edc", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ],
    [ "ParentText", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a372da0ad466934275ff7b0c4d4024ef3", null ],
    [ "RightBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a5a63000f5a2a2472e3e4ff55b3acea68", null ],
    [ "RightBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#aef3133d206f65e7c63e6f4e0b7e81a9b", null ],
    [ "TextSection", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a88ee79bd1b53330752b6a013f7c2cf65", null ],
    [ "TopBorder", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a17ab3611edf21b072bf9963d28fbba0d", null ],
    [ "TopBorderDistance", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a244f38805668926e16165aab20b80f01", null ],
    [ "VertOrient", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html#a06b5322c78bfdcb3086a7bfd82285d40", null ]
];
